netapp_ontap.models.storage_availability_zone_space API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.storage_availability_zone_space`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class StorageAvailabilityZoneSpaceSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the StorageAvailabilityZoneSpace object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `available: Size GET`

    Available space in the availability zone.

  `delayed_frees: Size GET`

    Total space used by the delayed frees in the availability zone.

  `efficiency_without_snapshots: StorageAvailabilityZoneSpaceEfficiencyWithoutSnapshots GET`

    Storage efficiency that does not include the savings provided by snapshots for the availability zone.

  `full_threshold_percent: Size GET PATCH`

    The availability zone full threshold percentage that triggers an EMS error.

  `inactive_data: Size GET`

    Inactive data in the availability zone.

  `log_and_recovery_metadata: Size GET`

    The total space consumed by system logs and cores in the availability zone.

  `logical_user_data_without_snapshots: Size GET`

    The logical space used by user data excluding snapshots in the availability zone.

  `nearly_full_threshold_percent: Size GET PATCH`

    The availability zone nearly full threshold percentage that triggers an EMS warning.

  `physical_used: Size GET`

    Total physical used space in the availability zone.

  `physical_used_percent: Size GET`

    The physical space used percentage in the availability zone.

  `physical_user_data_without_snapshots: Size GET`

    The physical space used by user data excluding snapshots in the availability zone.

  `size: Size GET`

    Total space in the availability zone.

  `total_metadata_used: Size GET`

    The total space consumed by metadata in the availability zone, which includes log and recovery metadata, delayed frees along with filesystem metadata and performance metadata.

  `unusable: Size GET`

    Total unusable space in the availability zone due to an aggregate being unavailable.